@@ -3,25 +3,26 @@ import logging
 import sys
 from flask import Flask
 from controller import init_blue_print
-from config import config, G, config_log
+from config import config, G
+from config.log_config import config_log
 from utils import parse_args
 import flask_cors
 
 
-def create_app():
+def create_app(env):
     logger = None
     app = Flask(__name__)
     flask_cors.CORS(app)
     app.config['JSON_AS_ASCII'] = False
-    env = os.environ.get('AI_ENV', 'default')
     app.config.from_object(config.get(env))
     init_blue_print(app)
     config_log()
-    # if config.get(env) == 'prd':
-    logger = logging.getLogger('gunicorn.error')
-    # else:
-    # logger = logging.getLogger('flask.app.module')
+    if env == 'prd':
+        logger = logging.getLogger('gunicorn')
+    else:
+        logger = logging.getLogger('console')
     G.logger = logger
+    app.logger = logger
     return app
 
 
@@ -38,21 +39,16 @@ __all__ = ['main']
 
 
 def main():
-    app = create_app()
     args = parse_args()
 
-    if args.cmd.isdigit():
-        cmd = 'runserver'
-        port = int(args.cmd)
+    if args.env:
+        app = create_app(args.env)
     else:
-        cmd = args.cmd
-        port = args.port if args.port else 8080
+        app = create_app("default")
 
-    if cmd == 'runserver':
-        app.run('0.0.0.0', port)
-        app.logger.info(f'run server at port {port}')
-    else:
-        print('run command error')
+    port = args.port if args.port else 8080
+    app.run('0.0.0.0', port)
+    app.logger.info(f'run server at port {port}')
 
 
 if __name__ == '__main__':
